<!-- Navigation -->
<nav class="navbar navbar-default navbar-fixed-top">
    <div class="container">
        <div class="navbar-header page-scroll">
            <button class="navbar-toggle" data-target="#bs-example-navbar-collapse-1" data-toggle="collapse" type="button"><span class="sr-only">Toggle navigation</span>
                <span class="icon-bar"></span> <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </button>
	    <a class="navbar-brand" href="{{ base_url }}">{{ config.site_name }}</a>
        </div>
        <div class="collapse navbar-collapse" id="bs-example-navbar-collapse-1">
            <ul class="nav navbar-nav navbar-right">
                <li class="hidden">
                    <a href="#page-top"></a>
                </li>
                {% for nav_item in nav %}
                <li>
                    <a href="{{ nav_item.url | url }}">{{ nav_item.title }}</a>
                </li>
                {% endfor %}
            </ul>
        </div>
    </div>
</nav>
