{% extend "base.html" %}

{% block content %}

<div class="content container">
    <div class="row">
        <div class="col-lg-12">
            <!-- Page Header -->
            <h2>{{ page.title }}</h2>
            {{ page.content }}
        </div>
    </div>
</div>

{% endblock %}
