<!DOCTYPE html>
<html lang="en">

	{% include "head.html" %}

	<body id="page-top">
		{% include "nav.html" %}
		<!-- Main Content -->
		{% block content %}
		{% if page.title == "Home" %}
		<header class="intro">
			<div class="intro-body">
				<div class="container">
					<div class="row">
						<div class="col-lg-12">
							{{ page.content }}
						</div>
					</div>
				</div>
			</div>
		</header>
		{% else %}
		<div class="content container">
			<div class="row">
				<div class="col-lg-12">
					{{ page.content }}
				</div>
			</div>
		</div>
		{% endif %}
		{% endblock %} 
		{% include "footer.html" %}
		{% include "scripts.html" %}
	</body>

</html>
