<!-- Footer -->
<footer class="text-center">
	<div class="footer-above">
		<div class="container">
			<div class="row">
				<hr>
				<div class="footer-col col-md-4">
					<h3>Connect</h3>
					<p><i class="fa fa-fw fa-envelope-o"></i>&nbsp;<a href="mailto:{{ config.extra.email }}">{{ config.extra.email }}</a><br>
					<i class="fa fa-fw fa-phone"></i>&nbsp;<a href="tel:{{ config.extra.phone }}">{{ config.extra.phone }}</a><br>
					</p>
				</div>
				<div class="footer-col col-md-4">
					<h3>Social</h3>
					<ul class="list-inline">
						{% for key, value in config.extra.social.items() %}
						<li>
							<a class="btn-social btn-outline" href="{{ value }}" target="_blank">
								<i class="fa fa-fw fa-{{ key | lower }}"></i>
							</a>
						</li>
						{% endfor %}
					</ul>
				</div>
				<div class="footer-col col-md-4" id="tags">
					<h3>Tags</h3>
					<div>
						<canvas id="tagcloud">
							<ul>
								{% for key in [
								"bootstrap",
								"css",
								"foss",
								"gpl",
								"javascript",
								"theme",
								"template" ] %}
								<li>
									<a href="#">{{ key }}</a>
								</li>
								{% endfor %}
							</ul>
						</canvas>
					</div>
				</div>
			</div>
		</div>
	</div>
	<div class="footer-below">
		<div class="container">
			<div class="row">
				<div class="col-lg-12">
					<div class="navbar-brand footer-copyright">
						{{ config.copyright | title }}
					</div>
					<ul class="nav navbar-nav navbar-right">
						<li>
							<a href="{{ base_url }}/sitemap.xml">Sitemap</a>
						</li>
					</ul>    
				</div>
			</div>
		</div>
</footer>

<div class="scroll-top page-scroll visible-xs visible-sm">
	<a class="btn btn-primary" href="#page-top">
		<i class="fa fa-chevron-up"></i></a>
</div>
