{% extends "base.html" %}

{% block content %}

<div class="content container">
    <div class="row">
        <div class="col-lg-12" style="text-align: center;">
            <h1 id="404-page-not-found">404</h1>
            <p>Page not found</p>
        </div>
    </div>
</div>

{% endblock %}