<!-- JQuery -->
<script src="{{ 'vendor/jquery/js/jquery.min.js' | url }}"></script>

<!-- Bootstrap Core Javascript -->
<script src="{{ 'vendor/bootstrap/js/bootstrap.min.js' | url }}"></script>

<!-- Plugin Javascript -->
<script src="{{ 'vendor/jasny-bootstrap/js/jasny-bootstrap.min.js' | url }}" type="text/javascript"></script>
<script src="{{ 'vendor/codrops/js/cbpAnimatedHeader.js' | url }}" type="text/javascript"></script>
<script src="{{ 'vendor/codrops/js/classie.js' | url }}" type="text/javascript"></script>
<script src="{{ 'vendor/jquery-tagcanvas/js/jquery.tagcanvas.min.js' | url }}" type="text/javascript"></script>
<script src="{{ 'vendor/typed.js/js/typed.min.js' | url }}" type="text/javascript"></script>

<!-- Custom Javascript -->
<script src="{{ 'js/script.js' | url }}" type="text/javascript"></script>
