<head>

    <meta charset="utf-8">
    <meta content="IE=edge" http-equiv="X-UA-Compatible">
    <meta content="width=device-width, initial-scale=1" name="viewport">
    <meta content="{{ config.site_description }}" name="description">
    <meta content="{{ config.site_author }}" name="author">
    <meta content="{{ config.extra.color }}" name="theme-color">

    <title>{{ config.site_name }}</title>

    <link rel="canonical" href="{{ page.canonical_url }}">

    <!-- Custom fonts for this template -->
    <link href="https://fonts.googleapis.com/css?family=Open+Sans|Raleway:300,400" rel="stylesheet" type="text/css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/fork-awesome@1.0.11/css/fork-awesome.min.css" integrity="sha256-MGU/JUq/40CFrfxjXb5pZjpoZmxiP2KuICN5ElLFNd8=" crossorigin="anonymous">

    <!-- Vendor styles for this template -->
    <link href="{{ 'vendor/bootswatch/css/bootstrap.min.css' | url }}" rel="stylesheet">
    <link href="{{ 'vendor/jasny-bootstrap/css/jasny-bootstrap.min.css' | url }}" rel="stylesheet">

    <!-- Custom styles for this template -->
    <link href="{{ 'css/style.css' | url }}" rel="stylesheet">

</head>
