body {
  width: 100%;
  height: 100%;
  overflow-x: hidden;
  font-family: "Open Sans", 'Raleway', sans-serif;
  font-weight: 300;
  color: #bbb;
}
html {
  width: 100%;
  height: 100%;
}
b {
  font-size: larger;
  font-weight: 300;
}
p {
  font-size: 18px;
  line-height: 1.5;
}
@media (min-width: 768px) {
  p {
    font-size: 20px;
    line-height: 1.6;
  }
}
p.small {
  font-size: 16px;
}
a,
a:hover,
a:focus,
a:active,
a.active {
  color: #ededed;
  outline: none;
}
h1,
h2,
h3,
h4,
h5,
h6 {
  font-family: 'Raleway', sans-serif;
  text-transform: uppercase;
  font-weight: 300;
}
.img-centered {
  margin: 0 auto;
}
header {
  text-align: center;
  background: transparent;
  color: white;
}
header .container, .content {
  padding-top: 100px;
  padding-bottom: 50px;
}
header img {
  display: block;
  margin: 0 auto 20px;
}
header .intro-text .name {
  border-bottom: 1px dotted #f00;
}
@media (min-width: 992px) {
  header .container {
    padding-top: 200px;
    padding-bottom: 100px;
  }
}
@media (min-width: 768px) {
  .navbar-fixed-top {
    padding: 25px 0;
    -webkit-transition: padding 0.3s;
    -moz-transition: padding 0.3s;
    transition: padding 0.3s;
  }
  .navbar-fixed-top .navbar-brand {
    -webkit-transition: all 0.3s;
    -moz-transition: all 0.3s;
    transition: all 0.3s;
    margin-left: 0;
  }
  .navbar-fixed-top .navbar-brand img {
    display: inline;
    width: 60px;
  }
  .navbar-fixed-top.navbar-shrink {
    padding: 10px 0;
    border-bottom: 1px solid rgba(255, 255, 255, 0.3);
  }
  .navbar-fixed-top.navbar-shrink .navbar-brand {
    font-size: 1.5em;
  }
  .navbar-fixed-top.navbar-shrink .navbar-brand img {
    margin-top: -5px;
  }
  .intro-body .brand-heading {
    font-size: 98px;
    white-space: nowrap ;
  }
  .intro-body .intro-text {
    font-size: 26px;
  }
}
.navbar {
  font-family: 'Raleway', sans-serif;
  text-transform: uppercase;
  font-weight: 300;
}
.navbar a:focus {
  outline: none;
}
.navbar .navbar-nav {
  letter-spacing: 1px;
}
.navbar .navbar-nav li a {
  color: white;
}
.navbar .navbar-nav li a:focus {
  outline: none;
}
.navbar .navbar-nav li a:hover {
  color: #adafae;
}
.navbar-default,
.navbar-inverse {
  border: none;
}
.navbar-brand > img {
  display: none;
}
.navbar-default,
.navbar-toggle,
.navbar-toggle:hover,
.navbar-default .navbar-toggle:focus,
.navbar-default .navbar-toggle:hover,
.navbar-default .navbar-toggle:focus {
  border: none;
  background-color: #060606;
}
.nav .open > a,
.nav .open > a:hover,
.nav .open > a:focus {
  background: transparent;
}

.nav>li>a:hover, .nav>li>a:focus {
    background: transparent;
    color: #adafae;
}

section {
  padding: 100px 0 50px 0;
}
section .row > div > h2 {
  margin: 0;
  font-size: 3em;
  padding-bottom: 1.5em;
}
section hr {
  margin-top: 0;
  max-width: 300px;
  border-top: 3px solid #282828;
}
.service-box {
  border-radius: 100%;
  width: 200px;
  height: 200px;
  padding: 35px;
  margin: 35px auto;
  border: 3px solid;
  -webkit-transition: width 5s;
  -moz-transition: width 5s;
  transition: width 5s;
}
.service-box a,
.service-box a:hover {
  text-decoration: none;
}
.service-box:hover {
  background: rgba(90, 0, 0, 0.8);
}

.pagination > .active > a {
  background-color: #010101;
  border-color: transparent;
}

.form-control {
  background-color: transparent;
  border-radius: 0;
}
label {
  font-weight: 300;
}
@media (max-width: 991px) {
    .footer-copyright {
        float: none;
    }
    .footer-below ul {
        display: none;
    }
}
@media (max-width: 767px) {
  section {
    padding: 75px 0;
  }
  section.first {
    padding-top: 75px;
  }
}
@media (min-height: 768px) {
  header .container {
    padding-top: 300px;
    padding-bottom: 300px;
  }
}
.posts {
  list-style-type: none;
}
.portfolio-item {
  margin: 0 0 15px;
  right: 0;
}
.portfolio-item .portfolio-link {
  display: block;
  position: relative;
  max-width: 400px;
  margin: 0 auto;
}
.portfolio-item .portfolio-link .caption {
  background: rgba(90, 0, 0, 0.8);
  position: absolute;
  width: 100%;
  height: 100%;
  opacity: 0;
  transition: all ease 0.5s;
  -webkit-transition: all ease 0.5s;
  -moz-transition: all ease 0.5s;
}
.portfolio-item .portfolio-link .caption:hover {
  opacity: 1;
}
.portfolio-item .portfolio-link .caption .caption-content {
  position: absolute;
  width: 100%;
  height: 20px;
  font-size: 20px;
  text-align: center;
  top: 50%;
  margin-top: -12px;
  color: white;
}
.portfolio-item .portfolio-link .caption .caption-content i {
  margin-top: -12px;
  color: rgba(255, 255, 255, 0.9);
}
.portfolio-item .portfolio-link .caption .caption-content h3,
.portfolio-item .portfolio-link .caption .caption-content h4 {
  margin: 0;
}
* {
  z-index: 2;
}
@media (min-width: 767px) {
  .portfolio-item {
    margin: 0 0 30px;
  }
}
@media (min-width: 768px) {
  .navbar-nav > li > div {
    padding-top: 15px;
    padding-bottom: 15px;
  }
}
@media (max-width: 767px) {
  #search {
    display: none;
  }
}
.btn-outline {
  color: white;
  font-size: 20px;
  border: solid 1px white;
  background: transparent;
  transition: all 0.3s ease-in-out;
  margin-top: 15px;
}
.btn-outline:hover,
.btn-outline:focus,
.btn-outline:active,
.btn-outline.active {
  color: #ededed;
  background: rgba(255, 255, 255, 0.1);
  border: solid 2px white;
}
.btn {
  text-transform: uppercase;
  font-family: "Open Sans", 'Raleway', sans-serif;
  font-weight: 300;
  -webkit-transition: all 0.3s ease-in-out;
  -moz-transition: all 0.3s ease-in-out;
  transition: all 0.3s ease-in-out;
  border-radius: 0;
}
.btn-default {
  border: 1px solid #f5f5f5;
  color: #f5f5f5;
  background-color: transparent;
}
.btn-default:hover,
.btn-default:focus {
  border: 1px solid #f5f5f5;
  outline: none;
  color: white;
  background-color: rgba(136, 0, 0, 0.3);
}
.btn-circle {
  width: 70px;
  height: 70px;
  margin-top: 15px;
  padding: 7px 16px;
  border: 2px solid white;
  border-radius: 100% !important;
  font-size: 40px;
  color: white;
  background: transparent;
  -webkit-transition: background 0.3s ease-in-out;
  -moz-transition: background 0.3s ease-in-out;
  transition: background 0.3s ease-in-out;
}
.btn-circle:hover,
.btn-circle:focus {
  outline: none;
  color: white;
  background: rgba(255, 255, 255, 0.1);
}
.btn-circle i.animated {
  -webkit-transition-property: -webkit-transform;
  -webkit-transition-duration: 1s;
  -moz-transition-property: -moz-transform;
  -moz-transition-duration: 1s;
}
.btn-circle:hover i.animated {
  -webkit-animation-name: pulse;
  -moz-animation-name: pulse;
  -webkit-animation-duration: 1.5s;
  -moz-animation-duration: 1.5s;
  -webkit-animation-iteration-count: infinite;
  -moz-animation-iteration-count: infinite;
  -webkit-animation-timing-function: linear;
  -moz-animation-timing-function: linear;
}
@-webkit-keyframes pulse {
  0 {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
  50% {
    -webkit-transform: scale(1.2);
    transform: scale(1.2);
  }
  100% {
    -webkit-transform: scale(1);
    transform: scale(1);
  }
}
@-moz-keyframes pulse {
  0 {
    -moz-transform: scale(1);
    transform: scale(1);
  }
  50% {
    -moz-transform: scale(1.2);
    transform: scale(1.2);
  }
  100% {
    -moz-transform: scale(1);
    transform: scale(1);
  }
}
.typed-cursor {
  opacity: 1;
  -webkit-animation: blink 0.9s infinite;
  -moz-animation: blink 0.9s infinite;
  animation: blink 0.9s infinite;
}
@keyframes blink {
  0% {
    opacity: 1;
  }
  50% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@-webkit-keyframes blink {
  0% {
    opacity: 1;
  }
  50% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@-moz-keyframes blink {
  0% {
    opacity: 1;
  }
  50% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
#canvas {
  margin-top: -20px;
}
footer {
  color: white;
}
footer h3 {
  margin-bottom: 30px;
}
footer .footer-above {
  background-color: transparent;
  margin-bottom: 35px;
}
footer .footer-col {
  margin-bottom: 50px;
}
footer .footer-below {
  padding: 25px 0;
  background-color: #060606;
  position: fixed !important;
  border: 0;
  bottom: 0;
  width: 100%;
}
.footer-below a {
    text-transform: uppercase;
}
.footer-copyright {
    font-size: 16px !important;
}

.footer-shrink {
    border-top: 1px solid rgba(255, 255, 255, 0.3) !important;
    padding: 10px 0 !important;
    margin-bottom: -5px;
}
.btn-social {
  display: inline-block;
  height: 50px;
  width: 50px;
  border: 2px solid white;
  border-radius: 100%;
  text-align: center;
  font-size: 20px;
  line-height: 45px;
}
.btn:focus,
.btn:active,
.btn.active {
  outline: none;
}
.scroll-top {
  position: fixed;
  right: 2%;
  bottom: 1.5%;
  width: 50px;
  height: 50px;
  z-index: 1049;
}
.scroll-top .btn {
  font-size: 20px;
  width: 50px;
  height: 50px;
  border-radius: 100%;
  line-height: 28px;
  border: none;
  background-color: transparent;
}
.scroll-top .btn:focus,
.scroll-top .btn:active {
  outline: none;
  background-color: transparent;
}
.portfolio-modal .modal-content {
  border-radius: 0;
  background-color: #060606;
  background-clip: border-box;
  -webkit-box-shadow: none;
  box-shadow: none;
  border: none;
  min-height: 100%;
  padding: 100px 0;
  text-align: center;
}
.portfolio-modal .modal-content h2 {
  margin: 0;
  font-size: 3em;
}
.portfolio-modal .modal-content img {
  margin-bottom: 30px;
}
.portfolio-modal .modal-content .item-details {
  margin: 30px 0;
}
.portfolio-modal .close-modal {
  position: absolute;
  width: 75px;
  height: 75px;
  background-color: transparent;
  top: 25px;
  right: 25px;
  cursor: pointer;
}
.portfolio-modal .close-modal:hover {
  opacity: 0.3;
}
.portfolio-modal .close-modal .lr {
  height: 75px;
  width: 1px;
  margin-left: 35px;
  background-color: #f5f5f5;
  transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  /* IE 9 */

  -webkit-transform: rotate(45deg);
  /* Safari and Chrome */

  z-index: 1051;
}
.portfolio-modal .close-modal .lr .rl {
  height: 75px;
  width: 1px;
  background-color: #f5f5f5;
  transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  /* IE 9 */

  -webkit-transform: rotate(90deg);
  /* Safari and Chrome */

  z-index: 1052;
}
.portfolio-modal .modal-backdrop {
  opacity: 0;
  display: none;
}

code {
  color: #809a00;
}
